@@ -80,7 +80,7 @@ class Letter(CompanyReport, metaclass=PoolMeta):
             letters[party] = PartyLetter(dunnings=current_dunnings,
                 payments=current_payments)
         report_context['letters'] = letters
-        with Transaction().set_context(company=header.get('company')):
+        with Transaction().set_context(company=header['company'].id):
             report_context['today'] = Date.today()
         report_context['get_payment_amount'] = cls.get_payment_amount
         report_context['get_payment_currency'] = cls.get_payment_currency
